BillingDetails class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

BillingDetails({Address? address, String? email, String? name, String? phone})
BillingDetails.fromJson(Map<String, dynamic> json)
factory

Properties

address Address?
Billing address.
final
email String?
Email address.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Full name.
final
phone String?
Billing phone number (including extension).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited