CheckoutSessionEvent class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CheckoutSessionEvent({required _EventObject object, required String id, required int created, required String type, required EventData<CheckoutSession> data, required bool livemode})
CheckoutSessionEvent.fromJson(Map<String, dynamic> json)
factory

Properties

created int
Time at which the object was created. Measured in seconds since the Unix epoch.
finalinherited
data EventData<CheckoutSession>
Object containing data associated with the event.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the object.
finalinherited
livemode bool
Whether the event is coming from live mode.
finalinherited
object → _EventObject
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Description of the event (e.g., invoice.created or charge.refunded).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited