CreateProductRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateProductRequest({String? id, required String name, bool active = true, String? description, Map<String, dynamic>? metadata, Map<String, dynamic>? defaultPriceData, List<Map<String, dynamic>>? features, List<String>? images, Map<String, dynamic>? packageDimensions, bool? shippable, String? statementDescriptor, String? taxCode, String? unitLabel, String? url})
CreateProductRequest.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
Whether the product is currently available for purchase. Defaults to true.
final
defaultPriceData Map<String, dynamic>?
Default price data for the product.
final
description String?
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
final
features List<Map<String, dynamic>>?
Optional array of hashes representing features.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account.
final
images List<String>?
Optional images for the product.
final
metadata Map<String, dynamic>?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
final
name String
The product’s name, meant to be displayable to the customer. (REQUIRED)
final
packageDimensions Map<String, dynamic>?
Optional package dimensions for the product.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippable bool?
Optional flag indicating whether the product is shippable.
final
statementDescriptor String?
Optional statement descriptor for the product.
final
taxCode String?
Optional tax code for the product.
final
unitLabel String?
Optional unit label for the product.
final
url String?
Optional URL for the product.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited