id property
Unique identifier for the object. This property is always present unless the invoice is an upcoming invoice.
Implementation
final String id;
Unique identifier for the object. This property is always present unless the invoice is an upcoming invoice.
final String id;