InvoiceSettings class

Annotations
  • @JsonSerializable.new()

Constructors

InvoiceSettings({String? defaultPaymentMethod})
InvoiceSettings.fromJson(Map<String, dynamic> json)
factory

Properties

defaultPaymentMethod String?
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited