ListSubscriptionItemsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ListSubscriptionItemsRequest({String? subscription, String? endingBefore, int? limit, String? startingAfter})
ListSubscriptionItemsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

endingBefore String?
A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startingAfter String?
A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
final
subscription String?
The ID of the subscription whose items will be retrieved.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited