limit property
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
Implementation
final int? limit;
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
final int? limit;