Message class abstract
- Implementers
- Address
- BalanceTransaction
- BillingDetails
- Charge
- CheckoutSession
- CreateSubscriptionScheduleRequest
- Customer
- Event
- Invoice
- ListSubscriptionSchedulesRequest
- PaymentIntent
- PaymentMethod
- PortalSession
- Price
- Product
- Refund
- Subscription
- SubscriptionItem
- SubscriptionSchedule
- SubscriptionSchedulePhase
- SubscriptionSchedulePhaseItem
- UpdateSubscriptionSchedulePhase
- UpdateSubscriptionSchedulePhaseItem
- UpdateSubscriptionScheduleRequest
Constructors
- Message()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited