PaymentMethodCard class
Properties
-
brand
→ String
-
Card brand.
final
-
displayBrand
→ String?
-
The brand to use when displaying the card, this accounts for customer’s
brand choice on dual-branded cards.
final
-
expMonth
→ int
-
Two-digit number representing the card’s expiration month.
final
-
expYear
→ int
-
Four-digit number representing the card’s expiration year.
final
-
fingerprint
→ String?
-
Uniquely identifies this particular card number. You can use this
attribute to check whether two customers who’ve signed up with you are
using the same card number, for example. For payment methods that tokenize
card information (Apple Pay, Google Pay), the tokenized number might be
provided instead of the underlying card number.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
last4
→ String
-
The last four digits of the card.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
wallet
→ Wallet?
-
If this Card is part of a card wallet, this contains the details of the
card wallet.
final