displayBrand property
The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards.
Implementation
final String? displayBrand;
The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards.
final String? displayBrand;