ProrationBehavior enum

Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting billing_cycle_anchor=now, or starting a trial), or if an item’s quantity changes.

Inheritance
Available extensions

Values

always_invoice → const ProrationBehavior

Always invoice immediately for prorations.

create_prorations → const ProrationBehavior

Will cause proration invoice items to be created when applicable. These proration items will only be invoiced immediately under certain conditions.

none → const ProrationBehavior

Disable creating prorations in this request.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProrationBehavior>
A constant List of the values in this enum, in order of their declaration.