cancelAt property
A date in the future at which the subscription will automatically get canceled.
Implementation
@TimestampConverter()
final DateTime? cancelAt;
A date in the future at which the subscription will automatically get canceled.
@TimestampConverter()
final DateTime? cancelAt;