endedAt property
If the subscription has ended, the date the subscription ended.
Implementation
@TimestampConverter()
final DateTime? endedAt;
If the subscription has ended, the date the subscription ended.
@TimestampConverter()
final DateTime? endedAt;