SubscriptionSchedule class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

SubscriptionSchedule({required _SubscriptionScheduleObject object, required String id, String? customer, Map<String, dynamic>? metadata, required List<SubscriptionSchedulePhase> phases, required SubscriptionScheduleStatus status, String? subscription})
const
SubscriptionSchedule.fromJson(Map<String, dynamic> json)
factory

Properties

customer String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
object → _SubscriptionScheduleObject
final
phases List<SubscriptionSchedulePhase>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SubscriptionScheduleStatus
final
subscription String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited