SubscriptionSchedulePhase class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

SubscriptionSchedulePhase({DateTime? startDate, DateTime? endDate, required List<SubscriptionSchedulePhaseItem> items})
const
SubscriptionSchedulePhase.fromJson(Map<String, dynamic> json)
factory

Properties

endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
items List<SubscriptionSchedulePhaseItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited