Wallet class

Annotations
  • @JsonSerializable.new()

Constructors

Wallet({required String type, String? dynamicLast4})
Wallet.fromJson(Map<String, dynamic> json)
factory

Properties

dynamicLast4 String?
The last four digits of the device account number. For tokenized numbers only.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the card wallet. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited