dynamicLast4 property
The last four digits of the device account number. For tokenized numbers only.
Implementation
final String? dynamicLast4;
The last four digits of the device account number. For tokenized numbers only.
final String? dynamicLast4;