type property

String type
final

The type of the card wallet. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.

Implementation

final String type;