stripe library
Classes
- Address
- https://stripe.com/docs/api/refunds/object
- AutomaticPaymentMethods
- AutomaticTax
- BalanceTransaction
- https://stripe.com/docs/api/balance_transactions/object
- BillingDetails
- https://docs.stripe.com/api/payment_methods/object#payment_method_object-billing_details
- Charge
- https://stripe.com/docs/api/charges/object
- ChargeEvent
- CheckoutSession
- https://stripe.com/docs/api/checkout/sessions/object
- CheckoutSessionEvent
- CreateCheckoutSessionRequest
- https://stripe.com/docs/api/checkout/sessions/create
- CreateCustomerRequest
- CreatePaymentIntentRequest
- https://stripe.com/docs/api/payment_intents/create
- CreatePortalSessionRequest
- https://stripe.com/docs/api/checkout/sessions/create
- CreatePriceRequest
- https://stripe.com/docs/api/prices/create
- CreateProductRequest
- https://stripe.com/docs/api/products/create
- CreateRefundRequest
- https://stripe.com/docs/api/checkout/refunds/create
- CreateSubscriptionScheduleRequest
- Customer
- https://stripe.com/docs/api/charges/object
- CustomerEvent
-
DataList<
T> -
Event<
T extends Message> - https://stripe.com/docs/api/events/object
-
EventData<
T> - FeeDetails
- Invoice
- https://docs.stripe.com/api/invoices/object
- InvoiceEvent
- InvoiceSettings
- The customer’s default invoice settings. https://docs.stripe.com/api/customers/object#customer_object-invoice_settings
- LineItem
- ListPricesRequest
- https://stripe.com/docs/api/prices/list
- ListProductsRequest
- https://stripe.com/docs/api/products/list
- ListSubscriptionItemsRequest
- https://docs.stripe.com/api/subscription_items/list
- ListSubscriptionSchedulesRequest
- ListSubscriptionsRequest
- https://stripe.com/docs/api/checkout/sessions/create
- Message
- PaymentIntent
- https://stripe.com/docs/api/payment_intents/object
- PaymentIntentData
- PaymentIntentEvent
- PaymentMethod
- PaymentMethod objects represent your customer’s payment instruments. You can use them with PaymentIntents to collect payments or save them to Customer objects to store instrument details for future payments.
- PaymentMethodCard
- https://docs.stripe.com/api/payment_methods/object#payment_method_object-card
- PaymentMethodDetails
- PaymentMethodDetailsCard
- PaymentMethodEvent
- PaymentMethodUsBankAccount
- https://docs.stripe.com/api/payment_methods/object#payment_method_object-us_bank_account
- PortalSession
- https://stripe.com/docs/api/customer_portal/session
- Price
- https://stripe.com/docs/api/charges/object
- PriceData
- PriceParameters
- Additional parameters for the price.
- Product
- https://stripe.com/docs/api/products/object
- ProductData
- Recurring
-
Recurring components of a price such as
intervalandusage_type. - Refund
- https://stripe.com/docs/api/refunds/object
- RefundEvent
- ShippingSpecification
- https://stripe.com/docs/api/payment_intents/create#create_payment_intent-shipping
- Stripe
- Stripe is the Class that provides the Interface for external calls via the Stripe API.
- StripeApiError
- Subscription
- https://stripe.com/docs/api/subscriptions/object
- SubscriptionData
- SubscriptionEvent
- SubscriptionItem
- https://stripe.com/docs/api/charges/object
- SubscriptionItemUpdate
- https://docs.stripe.com/api/subscription_items/update
- SubscriptionSchedule
- SubscriptionSchedulePhase
- SubscriptionSchedulePhaseItem
- SubscriptionUpdate
- https://docs.stripe.com/api/subscriptions/update
- TaxIdCollection
- UpdateCustomerRequest
- https://stripe.com/docs/api/checkout/customers/update
- UpdateSubscriptionSchedulePhase
- UpdateSubscriptionSchedulePhaseItem
- UpdateSubscriptionScheduleRequest
- Wallet
- https://docs.stripe.com/api/payment_methods/object#payment_method_object-card-wallet
Enums
- AggregateUsage
- BillingAddressCollection
- PaymentBehavior
- PaymentMethodType
- PriceType
- ProrationBehavior
- Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting billing_cycle_anchor=now, or starting a trial), or if an item’s quantity changes.
- RecurringInterval
- SessionMode
- SetupFutureUsage
- StripeApiErrorType
- SubscriptionScheduleEndBehavior
- SubscriptionScheduleStatus
- SubscriptionStatus
Properties
- log → Logger
-
final
Functions
-
isValidWebhookIpAddress(
String ipAddress) → bool - Returns true if the provided ip address is of of the white listed Stripe webhook ip addresses.
-
isValidWebhookSignature(
String signature, String body, String signingSecret, Duration timeTolerance) → bool - Returns wether the signature is correctly signed and within the tolerated time window.