CreatePriceRequest class
Properties
-
active
→ bool?
-
Whether the price can be used for new purchases. Defaults to true.
final
-
currency
→ String
-
Three-letter ISO currency code, in lowercase. Must be a supported currency. (REQUIRED)
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<String, dynamic>?
-
Set of key-value pairs that you can attach to an object.
final
-
nickname
→ String?
-
A brief description of the price, hidden from customers.
final
-
parameters
→ PriceParameters?
-
Additional parameters for the price.
final
-
product
→ String?
-
The ID of the product that this price will belong to. (REQUIRED UNLESS PRODUCT_DATA IS PROVIDED)
final
-
recurring
→ Recurring?
-
The recurring components of a price such as interval and usage_type.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
unitAmount
→ int?
-
A positive integer in cents (or 0 for a free price) representing how much to charge.
One of unit_amount or custom_unit_amount is required, unless billing_scheme=tiered. (REQUIRED CONDITIONALLY)
final