Constructors
-
Event({required _EventObject object, required String id, required int created, required EventData<T> data, required String type, required bool livemode})
-
Properties
-
created
→ int
-
Time at which the object was created. Measured in seconds since the Unix
epoch.
final
-
data
↔ EventData<T>
-
Object containing data associated with the event.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
Unique identifier for the object.
final
-
livemode
→ bool
-
Whether the event is coming from live mode.
final
-
object
→ _EventObject
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ String
-
Description of the event (e.g., invoice.created or charge.refunded).
final