EventData<T> class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- object → T
-
final
-
previousAttributes
→ Map<
String, dynamic> ? -
Object containing the names of the updated attributes and their values
prior to the event (only included in events of type *.updated).
If an array attribute has any updated elements, this object contains the
entire array.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
Object toJsonT(T value)) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited