Invoice class
Constructors
-
Invoice({required String id, required String currency, required String customer, required int total, String? description, String? hostedInvoiceUrl, String? status, String? subscription, String? paymentIntent, String? accountCountry, String? accountName})
-
-
Invoice.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
accountCountry
→ String?
-
The country of the business associated with this invoice, most often the
business creating the invoice.
final
-
accountName
→ String?
-
The public name of the business associated with this invoice, most often
the business creating the invoice.
final
-
currency
→ String
-
Three-letter ISO currency code, in lowercase. Must be a supported
currency.
final
-
customer
→ String
-
The ID of the customer who will be billed.
final
-
description
→ String?
-
An arbitrary string attached to the object. Often useful for displaying
to users. Referenced as ‘memo’ in the Dashboard.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hostedInvoiceUrl
→ String?
-
The URL for the hosted invoice page, which allows customers to view and
pay an invoice. If the invoice has not been finalized yet, this will be
null.
final
-
id
→ String
-
Unique identifier for the object. This property is always present unless
the invoice is an upcoming invoice.
final
-
paymentIntent
→ String?
-
The PaymentIntent associated with this invoice. The PaymentIntent is
generated when the invoice is finalized, and can then be used to pay the
invoice. Note that voiding an invoice will cancel the PaymentIntent.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ String?
-
The status of the invoice, one of draft, open, paid, uncollectible, or
void.
final
-
subscription
→ String?
-
The subscription that this invoice was prepared for, if any.
final
-
total
→ int
-
Total after discounts and taxes.
final