hostedInvoiceUrl property
The URL for the hosted invoice page, which allows customers to view and pay an invoice. If the invoice has not been finalized yet, this will be null.
Implementation
final String? hostedInvoiceUrl;
The URL for the hosted invoice page, which allows customers to view and pay an invoice. If the invoice has not been finalized yet, this will be null.
final String? hostedInvoiceUrl;