PaymentMethodUsBankAccount class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PaymentMethodUsBankAccount({String? bankName, String? fingerprint, String? last4, String? routingNumber})
-
PaymentMethodUsBankAccount.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bankName → String?
-
The name of the bank.
final
- fingerprint → String?
-
Uniquely identifies this particular bank account. You can use this
attribute to check whether two bank accounts are the same.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- last4 → String?
-
Last four digits of the bank account number.
final
- routingNumber → String?
-
Routing number of the bank account.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited