PriceParameters class
Additional parameters for the price.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
PriceParameters({int? customUnitAmount, ProductData? productData, List<
Map< ? tiers, String? tiersMode, String? billingScheme, Map<String, dynamic> >String, dynamic> ? currencyOptions, String? lookupKey, String? taxBehavior, String? transferLookupKey, Map<String, dynamic> ? transformQuantity, double? unitAmountDecimal}) -
PriceParameters.fromJson(Map<
String, dynamic> json) -
factory
Properties
- billingScheme → String?
-
Billing scheme for the price.
final
-
currencyOptions
→ Map<
String, dynamic> ? -
Optional currency options for the price.
final
- customUnitAmount → int?
-
Custom unit amount for the price. (REQUIRED UNLESS UNIT_AMOUNT IS PROVIDED)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lookupKey → String?
-
Lookup key for the price.
final
- productData → ProductData?
-
Additional data for the product. (REQUIRED UNLESS PRODUCT IS PROVIDED)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxBehavior → String?
-
Tax behavior for the price.
final
-
tiers
→ List<
Map< ?String, dynamic> > -
Tiers for the price. (REQUIRED IF BILLING_SCHEME=TIERED)
final
- tiersMode → String?
-
Mode for using tiers. (REQUIRED IF BILLING_SCHEME=TIERED)
final
- transferLookupKey → String?
-
Transfer lookup key for the price.
final
-
transformQuantity
→ Map<
String, dynamic> ? -
Transform quantity for the price.
final
- unitAmountDecimal → double?
-
Optional unit amount decimal for the price.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited