Recurring class
Recurring components of a price such as interval and usage_type.
- Annotations
-
- @JsonSerializable.new()
Constructors
- Recurring({required RecurringInterval interval, AggregateUsage? aggregateUsage, int? intervalCount, String? usageType})
-
Recurring.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aggregateUsage → AggregateUsage?
-
Specifies a usage aggregation strategy for prices of
usage_type=metered. Allowed values aresumfor summing up all usage during a period,last_during_periodfor using the last usage record reported within a period,last_everfor using the last usage record ever (across period bounds) ormaxwhich uses the usage record with the maximum reported usage during a period. Defaults tosum.final - hashCode → int
-
The hash code for this object.
no setterinherited
- interval → RecurringInterval
-
Specifies billing frequency. Either
day,week,month, oryear. (REQUIRED)final - intervalCount → int?
-
The number of intervals between subscription billings.
For example,
interval=monthandinterval_count=3bills every 3 months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usageType → String?
-
Configures how the quantity per period should be determined.
Can be either
meteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited