SubscriptionItemUpdate class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
SubscriptionItemUpdate({PaymentBehavior? paymentBehavior, Map<String, String>? metadata, String? price, ProrationBehavior? prorationBehavior, int? quantity, Map<String, Object?>? billingThresholds, bool? offSession, Map<String, Object?>? priceData, DateTime? prorationDate, List<String>? taxRates})
-
-
SubscriptionItemUpdate.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
billingThresholds
→ Map<String, Object?>?
-
Define thresholds at which an invoice will be sent,
and the subscription advanced to a new billing period.
When updating, pass an empty string to remove previously-defined thresholds.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<String, String>?
-
Set of key-value pairs that you can attach to an object.
final
-
offSession
→ bool?
-
Indicates if a customer is on or off-session while an invoice payment is attempted.
final
-
paymentBehavior
→ PaymentBehavior?
-
final
-
price
→ String?
-
The ID of the price object. When changing a subscription item’s price,
quantity is set to 1 unless a quantity parameter is provided.
final
-
priceData
→ Map<String, Object?>?
-
Data used to generate a new Price object inline.
final
-
prorationBehavior
→ ProrationBehavior?
-
Determines how to handle prorations when the billing cycle changes
(e.g., when switching plans, resetting billing_cycle_anchor=now,
or starting a trial), or if an item’s quantity changes.
The default value is create_prorations.
final
-
prorationDate
→ DateTime?
-
If set, the proration will be calculated as though the subscription was updated at the given time.
This can be used to apply the same proration that was previewed with the upcoming invoice endpoint.
final
-
quantity
→ int?
-
The quantity you’d like to apply to the subscription item you’re creating.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
taxRates
→ List<String>?
-
final