billingThresholds property
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
Implementation
final Map<String, Object?>? billingThresholds;