prorationDate property
If set, the proration will be calculated as though the subscription was updated at the given time. This can be used to apply the same proration that was previewed with the upcoming invoice endpoint.
Implementation
final DateTime? prorationDate;